package openstates

type BillNode struct {
	Id                 string
	LegislativeSession *LegislativeSessionNode
	Identifier         string
	Title              string
	FromOrganization   string
	Classification     []string
	Subject            []string
	Abstracts          []BillAbstractNode
	OtherTitles        []BillTitleNode
	OtherIdentifiers   []BillIdentifierNode
	Actions            []BillActionNode
	Sponsorships       []BillSponsorshipNode
	RelatedBills       []RelatedBillNode
	Versions           []BillDocumentNode
	Documents          []BillDocumentNode
	Votes              []VoteEventNode
	Sources            []LinkNode
	OpenStatesUrl      string
	CreatedAt          string
	UpdatedAt          string
	Extras             string
}

type BillAbstractNode struct {
	Abstract string
	Note     string
	Date     string
}

type BillTitleNode struct {
	Title string
	Note  string
}

type BillIdentifierNode struct {
	Identifier string
	Scheme     string
	Note       string
}

type BillActionNode struct {
	Organization    *OrganizationNode
	Description     string
	Date            string
	Classification  []ActionType
	Order           int
	Extras          string
	Vote            *VoteEventNode
	RelatedEntities []RelatedEntityNode
}

type RelatedEntityNode struct {
	Name         string
	EntityType   EntityType
	Organization *OrganizationNode
	Person       *PersonNode
}

type BillSponsorshipNode struct {
	Name           string
	EntityType     EntityType
	Organization   *OrganizationNode
	Person         *PersonNode
	Primary        bool
	Classification string
}

type RelatedBillNode struct {
	Identifier         string
	LegislativeSession string
	RelationType       string
	RelatedBill        *BillNode
}

type BillDocumentNode struct {
	Note  string
	Date  string
	Links []MimetypeLinkNode
}

type MimetypeLinkNode struct {
	MediaType string
	Url       string
	Text      string
}

type VoteEventNode struct {
	Id                   string
	Identifier           string
	MotionText           string
	MotionClassification []string
	StartDate            string
	Result               string
	Organization         *OrganizationNode
	BillAction           *BillActionNode
	Votes                []PersonVoteNode
	Counts               []VoteCountNode
	Sources              []string
	CreatedAt            string
	UpdatedAt            string
	Extras               string
}

type PersonVoteNode struct {
	Option    string
	VoterName string
	Voter     *PersonNode
	Note      string
}

type VoteCountNode struct {
	Option string
	Value  int
}
